# frozen_string_literal: true

module ESI
  class Client
    # ESI wars operations.
    module War
      # Return details about a war.
      #
      # This endpoint is cached for up to 3600 seconds.
      #
      # @esi_version dev
      # @esi_version legacy
      # @esi_version v1
      #
      # @param war_id [Integer] ID for a war
      # @param params [Hash] Additional query string parameters
      # @param headers [Hash] Additional headers
      #
      # @raise [ESI::Errors::BadRequestError] Bad request
      # @raise [ESI::Errors::ErrorLimitedError] Error limited
      # @raise [ESI::Errors::UnprocessableEntityError] War not found
      # @raise [ESI::Errors::InternalServerError] Internal server error
      # @raise [ESI::Errors::ServiceUnavailableError] Service unavailable
      # @raise [ESI::Errors::GatewayTimeoutError] Gateway timeout
      #
      # @see https://esi.evetech.net/ui/#/Wars/get_wars_war_id
      def get_war(war_id:, headers: {}, params: {})
        get("/wars/#{war_id}/", headers: headers, params: params)
      end
      alias get_wars_war_id get_war

      # Return a list of kills related to a war.
      #
      # This endpoint is cached for up to 3600 seconds.
      #
      # @esi_version dev
      # @esi_version legacy
      # @esi_version v1
      #
      # @param war_id [Integer] A valid war ID
      # @param params [Hash] Additional query string parameters
      # @param headers [Hash] Additional headers
      #
      # @raise [ESI::Errors::BadRequestError] Bad request
      # @raise [ESI::Errors::ErrorLimitedError] Error limited
      # @raise [ESI::Errors::UnprocessableEntityError] War not found
      # @raise [ESI::Errors::InternalServerError] Internal server error
      # @raise [ESI::Errors::ServiceUnavailableError] Service unavailable
      # @raise [ESI::Errors::GatewayTimeoutError] Gateway timeout
      #
      # @see https://esi.evetech.net/ui/#/Wars/get_wars_war_id_killmails
      def get_war_killmails(war_id:, headers: {}, params: {})
        get("/wars/#{war_id}/killmails/", headers: headers, params: params)
      end
      alias get_wars_war_id_killmails get_war_killmails

      # Return a list of wars.
      #
      # This endpoint is cached for up to 3600 seconds.
      #
      # @esi_version dev
      # @esi_version legacy
      # @esi_version v1
      #
      # @param max_war_id [Integer] Only return wars with ID smaller than this
      # @param params [Hash] Additional query string parameters
      # @param headers [Hash] Additional headers
      #
      # @raise [ESI::Errors::BadRequestError] Bad request
      # @raise [ESI::Errors::ErrorLimitedError] Error limited
      # @raise [ESI::Errors::InternalServerError] Internal server error
      # @raise [ESI::Errors::ServiceUnavailableError] Service unavailable
      # @raise [ESI::Errors::GatewayTimeoutError] Gateway timeout
      #
      # @see https://esi.evetech.net/ui/#/Wars/get_wars
      def get_wars(max_war_id: nil, headers: {}, params: {})
        params.merge!("max_war_id" => max_war_id)
        get("/wars/", headers: headers, params: params)
      end
    end
  end
end
